@@ -38,12 +38,12 @@ def set_viewer_options(to_exclude=None, usetex=False, **kwargs):
     # For axes, set spacing (pad) and size of label and title
     plt.rc("axes", labelpad=0, labelsize=25, titlepad=17, titlesize=25)
 
-    # Set default text charactieristics.
+    # Set default text characteristics.
     # Possible weight values are:
     # 100, 200, 300, 400 / "normal", 500, 600, 700 / "bold", 800, 900.
+    plt.rc("font", family="serif", size=20, weight=400)
     if usetex:
-        plt.rc("font", family="serif", serif=["Times"])
-    plt.rc("font", size=20, weight=400)
+        plt.rc("font", serif=["Times"])
 
     # Set default font size for legends.
     plt.rc("legend", fontsize=16)
