@@ -41,16 +41,18 @@ def test_dated():
         assert not dated.time
 
 def test_dated_sorting():
-    timestamp = "19990405_120394"
-    for path in [timestamp, Path(timestamp)]:
+    timestamp1 = "19990405_120394"
+    timestamp2 = "19990405_120395"
+    for path in [timestamp1, Path(timestamp1)]:
         dated1 = skrt.core.Dated(path)
-        dated2 = skrt.core.Dated(auto_timestamp=True)
-        assert dated2 > dated1
-        assert dated2 >= dated1
-        assert dated1 < dated2
-        assert dated1 <= dated2
-        assert dated1 == dated1
-        assert dated1 != dated2 
+        for dated2 in [skrt.core.Dated(timestamp2),
+                       skrt.core.Dated(auto_timestamp=True)]:
+            assert dated2 > dated1
+            assert dated2 >= dated1
+            assert dated1 < dated2
+            assert dated1 <= dated2
+            assert dated1 == dated1
+            assert dated1 != dated2 
 
 def test_dated_interval():
     timestamp = "20010502_120358"
@@ -306,7 +308,7 @@ def test_tictoc():
     # and level of agreement required in timing tests.
     n_iteration = 3
     sleep_time = 0.25
-    small_number = 1.e-3
+    small_number = 1.e-2
 
     # Start timer.
     t1 = timeit.default_timer()
@@ -333,6 +335,24 @@ def test_tictoc():
         t5 = timeit.default_timer()
         assert tic_toc == approx(t5 - t2, abs=small_number)
 
+def test_tictoc_messages(capsys):
+    """Test output from toc() command."""
+    # Check that TicToc().default_message is output
+    # when TicToc().message is True.
+    skrt.core.TicToc(True)
+    assert skrt.core.TicToc().message is True
+    skrt.core.tic()
+    skrt.core.toc()
+    assert skrt.core.TicToc().default_message
+    assert skrt.core.TicToc().default_message in capsys.readouterr().out
+
+    # Check that empty string is output
+    # when TicToc().message is False.
+    skrt.core.TicToc(False)
+    assert skrt.core.TicToc().message is False
+    skrt.core.toc()
+    assert capsys.readouterr().out == ""
+
 def test_qualified_name():
     """Test determination of qualified name for a class."""
     from skrt.core import Archive
@@ -404,3 +424,13 @@ def test_qualified_name():
 
     # Check value returned for non-class.
     assert skrt.core.qualified_name(5) == None
+
+def test_compress_user():
+    """Test replacement by '~' of user home directory at start of path."""
+    home = Path(skrt.core.fullpath("~"))
+    not_home = "/not/home"
+    # Protect against unlikely case where home directory is "/not/home"...
+    if not_home in str(home):
+        not_home = "/not/second/home"
+    assert skrt.core.compress_user(home) == "~/."
+    assert skrt.core.compress_user(not_home) == skrt.core.fullpath(not_home)
