@@ -15,7 +15,8 @@ from pydicom._storage_sopclass_uids import\
         PositronEmissionTomographyImageStorage
 
 from skrt.core import Defaults, File, fullpath
-from skrt.image import (Image, checked_crop_limits, get_alignment_translation,
+from skrt.image import (_slice_axes, Image,
+                        checked_crop_limits, get_alignment_translation,
                         get_geometry, get_image_comparison_metrics,
                         get_mask_bbox, get_translation_to_align,
                         match_images, match_image_voxel_sizes, rescale_images)
@@ -1708,3 +1709,27 @@ def test_get_sinogram():
     assert sinogram.get_extents()[1][1] > nxyz / 2
     assert sinogram.get_extents()[1][0] == -sinogram.get_extents()[1][1]
     assert sinogram.get_extents()[2] == (-nxyz / 2, nxyz / 2)
+
+def test_flattened():
+    """Test creation of flattened image."""
+    # Create inital image.
+    im1 = create_test_image(shape, voxel_size, origin)
+
+    # Check characteristics of flattened image for each view.
+    for view, ax in _slice_axes.items():
+        im2 = im1.flattened(view)
+
+        assert im2.get_data().sum() == im1.get_data().sum()
+        assert im2.get_extents() == im1.get_extents()
+
+        n_voxels2 = list(im1.get_n_voxels())
+        n_voxels2[ax] = 1
+        assert im2.get_n_voxels() == n_voxels2
+
+        voxel_size2 = list(im1.get_voxel_size())
+        voxel_size2[ax] = im1.get_length(ax)
+        assert im2.get_voxel_size() == voxel_size2
+
+        origin2 = list(im1.get_origin())
+        origin2[ax] = im1.get_extents()[ax][0] + 0.5 * im1.get_length(ax)
+        assert im2.get_origin() == origin2
