@@ -11,12 +11,14 @@ import pytest
 import numpy as np
 import matplotlib.colors
 
+from shapely import minimum_bounding_circle
 from shapely.geometry import Polygon
 from shapely.validation import explain_validity
 
 from skimage.morphology import ball
 
 from skrt.core import fullpath, Defaults
+from skrt.image import _slice_axes
 from skrt.simulation import SyntheticImage
 from skrt.structures import contour_to_polygon, polygon_to_contour, \
         StructureSet, ROI, interpolate_points_single_contour, \
@@ -1906,3 +1908,156 @@ def test_apl_from_masks():
         assert cuboid1.get_added_path_length(cuboid2, single_slice=True) == apl1
         assert (cuboid1.get_added_path_length(cuboid2)
                 == apl1 * dxyz)
+
+def test_flattened():
+    """Test creation of flattened ROI."""
+    # Create initial ROI
+    sim = SyntheticImage((10, 10, 10), origin=(0.5, 0.5, 0.5))
+    sides = (4, 2, 6)
+    sim.add_cuboid(sides, name="cuboid")
+    roi1 = sim.get_roi("cuboid")
+
+    # Check characteristics of flattened ROI for each view.
+    for view, ax in _slice_axes.items():
+        roi2 = roi1.flattened(view)
+
+        assert roi2.get_extents() == roi1.get_extents()
+        assert np.all(roi2.get_centroid() == roi1.get_centroid())
+
+        voxel_size = list(roi1.get_voxel_size())
+        voxel_size[ax] = sides[ax]
+        assert roi2.get_voxel_size() == voxel_size
+        assert roi2.name == f"{roi1.name}_flattened"
+
+def test_enclosing_roi():
+    """Test creation of ROI that encloses another."""
+    # Create ROIs representing cuboid and cylinder from polygons.
+    xy = 2
+    z = 5
+    square = Polygon([(-xy, -xy), (-xy, xy), (xy, xy), (xy, -xy), (-xy, -xy)])
+    circle = minimum_bounding_circle(square)
+    roi1 = ROI({key: [square] for key in range(z)}, name="cuboid")
+    roi2 = ROI({key: [circle] for key in range(z)}, name="cylinder")
+
+    # Check characteristics of enclosing ROIs,
+    # with and without rotations allowed.
+    # ROI and enclosing ROI are the same for the cuboid,
+    # but are different for the cylinder.
+    for oriented in [True, False]:
+        for roi in [roi1, roi2]:
+            roi3 = roi.get_enclosing_roi(oriented)
+
+            if roi.name == "cuboid":
+                extents = roi.get_extents()
+                volume = roi.get_volume()
+            else:
+                envelope = (circle.oriented_envelope if oriented
+                            else circle.envelope)
+                x1, y1, x2, y2 = envelope.bounds
+                z1, z2 = roi.get_extents()[2]
+                extents = [[x1, x2], [y1, y2], [z1, z2]]
+                volume = envelope.area * z
+
+            assert roi3.get_extents() == extents
+            assert roi3.get_volume() == volume
+            assert np.all(roi3.get_centroid()
+                          == pytest.approx(roi.get_centroid(), abs=1e-15))
+            assert roi3.name == f"{roi.name}_envelope"
+
+def test_containing_image():
+    '''Test retrieval of image containing specified ROIs.'''
+
+    # Create synthetic image with associated structure set.
+    sim = SyntheticImage((100, 100, 100))
+    sim.add_cube(side_length=40, name="cube", centre=(30, 30, 60), intensity=1)
+    sim.add_sphere(radius=20, name="sphere", centre=(70, 70, 40), intensity=10)
+    sset = sim.get_structure_set()
+
+    # Define items for testing.
+    voxel_size1 = [1, 1, 1]
+    voxel_size2 = [1, 2, 3]
+    sim2 = SyntheticImage((10, 10, 10), voxel_size=voxel_size2)
+    names = sset.get_roi_names()
+    names.insert(1, "missing_roi")
+
+    # Check that original image is returned as conaining image.
+    assert sset.containing_image(names, sim) is sim
+
+    # Check that results are as expected
+    # for different arguments to sset.containing_image()
+    tests = [
+            ((names,), voxel_size1),
+            ((names, sim2), voxel_size2),
+            ((names, None, voxel_size2), voxel_size2),
+            ]
+    for args, voxel_size in tests:
+        img = sset.containing_image(*args)
+        assert img.get_voxel_size() == voxel_size
+        assert sset.contains(sset.get_roi_names(), img)
+
+def test_write_multilabel_nifti():
+    '''Test writing of structure set to multi-label NIfTI file.'''
+
+    # Create synthetic image with associated structure set.
+    sim = SyntheticImage((100, 100, 100))
+    sim.add_cube(side_length=40, name="cube", centre=(30, 30, 60), intensity=1)
+    sim.add_sphere(radius=20, name="sphere", centre=(70, 70, 40), intensity=10)
+    sset = sim.get_structure_set()
+    rois = sset.get_rois()
+    n_roi = len(rois)
+
+    # Create list of ROI names, including name for non-existant ROI.
+    names = sset.get_roi_names()
+    names.insert(1, "missing_roi")
+
+    # Define name of output file.
+    ext = ".nii.gz"
+    outname = f"RTSTRUCT_{sset.timestamp}{ext}"
+
+    # Define the path to the output director,
+    # and ensure that it doesn't initially exist.
+    nii_dir = pathlib.Path("tmp/nii_multilabel")
+    if nii_dir.exists():
+        shutil.rmtree(nii_dir)
+
+    # Define test values for names parameter of StructureSet.write().
+    names_tests = [
+            None,
+            {names[idx] : f"ROI {idx + 1}" for idx in range(len(names))},
+            sset.get_roi_names(),
+            tuple(names),
+            ]
+
+    # Perform tests without and with overwriting of output directory,
+    # which initially doesn't exist.
+    for overwrite in [False, True]:
+        # Write structure set as multi-label NIfTI file.
+        sset.write(outdir=nii_dir, ext=ext, overwrite=overwrite,
+                   multi_label=True, names=names)
+        # Check that a single file is created.
+        paths = list(nii_dir.glob("*"))
+        assert 1 == len(paths)
+        # Check that path of output file is as expected.
+        path = paths[0]
+        assert path == nii_dir / outname
+
+        # Read back the structure-set data,
+        # using different values for the names parameter.
+        for idx in range(len(names_tests)):
+            rois2 = StructureSet(path, multi_label=True,
+                                 names=names_tests[idx]).get_rois()
+            # Check that the number of ROIs read from file is as expected.
+            assert n_roi == len(rois2)
+
+            # Check ROIs of structure set read from file.
+            for jdx in range(n_roi):
+                # Check ROI names.
+                if idx > 0:
+                    assert rois[jdx].get_name() == rois2[jdx].get_name()
+                else:
+                    assert (f"ROI {1 + names.index(rois[jdx].get_name())}"
+                            == rois2[jdx].get_name())
+                # Check ROI volumes.
+                assert rois[jdx].get_volume() == rois2[jdx].get_volume()
+                # Check ROI masks.
+                assert np.all(rois[jdx].get_mask() == rois2[jdx].get_mask())
